@@ -229,13 +229,13 @@ class Vector(object):
         self.vector = vector
 
     def vector_names(self):
-        names = [0] * (len(self.params.keys()))
+        names = [0] * (len(self.params.keys()) + 2)
         for key in self.params.keys():
             try:
                 names[self.indices[key]] = key
             except KeyError:
                 pass
-        self.names = names
+        self.names = [i for i in names if type(i) == str]
 
     def vector_to_dict(self):
         for key in self.params.keys():
