@@ -40,7 +40,7 @@ cmap = nipy_spectral
 rcParams['font.size'] = 9
 rcParams['lines.markersize'] = 5
 rcParams['axes.grid'] = False
-default_colors = ['orange', 'purple', 'magenta', 'pink', 'green', 'grey', 'red']
+default_colors = ['orange', 'purple', 'magenta', 'pink', 'green', 'grey', 'red', 'blue', 'yellow']
 
 highlight_format = dict(marker='o', ms=16, mfc='none', mew=2, mec='gold', zorder=99)
 
